sr_scale: sr_scale

View source: R/micss.R

sr_scaleR Documentation

sr_scale

Description

Computes the scale parameter for the GEV approximation to the distribution of kappa_test statistic

Usage

sr_scale(t, alpha, lmax = NULL)

Arguments

t

Sample size

alpha

Value of the tail index between 2 and 4

lmax

Maximum lag to be used for the long-run estimation of the fourth order moment of the innovations. If not specified it is generated automatically depending on the sample size.

Details

Used internally by cv.kappa and p.val.kappa

Value

Scale parameter

References

J.L. Carrion-i-Silvestre & A. Sansó (2026): Testing for Constant Unconditional Variance in Heavy-Tailed Time Series. Communications in Statistics - Simulation and Computation. doi:10.1080/03610918.2026.2615207


micss documentation built on March 17, 2026, 5:06 p.m.

Related to sr_scale in micss...