var.est.icss: var.est.icss

View source: R/micss.R

var.est.icssR Documentation

var.est.icss

Description

Computes the variance of each period according to the breaks found with icss or micss.

Usage

var.est.icss(x)

Arguments

x

An object with the output of icss or micss.

Value

A vector with the variances.


micss documentation built on March 17, 2026, 5:06 p.m.

Related to var.est.icss in micss...